package demo.tablecellrenderer;

import java.awt.Color;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

import demo.tablecellrenderer.renderer.ColorRenderer;
import demo.tablecellrenderer.renderer.IconRenderer;
import demo.tablecellrenderer.renderer.PercentageRenderer;
import demo.tablecellrenderer.renderer.SimpleColumnBackgroundRenderer;

@SuppressWarnings("serial")
public class RendererChainDemo extends JFrame
{ 
  public static void main(String[] args) throws Exception
  {
    UIManager.setLookAndFeel("de.javasoft.plaf.synthetica.SyntheticaStandardLookAndFeel");
    UIManager.put("Table.alternateRowColor", new Color(0xF3FFFF));
    
    EventQueue.invokeLater(new Runnable()
    {
      public void run()
      {        
        new RendererChainDemo();
      }
    });
  }
  
  public RendererChainDemo()
  {
    JTable table = new JTable(new DemoTableModel(100));

    TableCellRenderer defaultRenderer = table.getDefaultRenderer(Object.class);
    // colorize column background
    TableCellRenderer backgroundRenderer = new SimpleColumnBackgroundRenderer(defaultRenderer);
    // format numbers as percentages
    TableCellRenderer percentageRenderer = new PercentageRenderer(backgroundRenderer);
    // mark values with an icon which are evenly divisable by 5
    TableCellRenderer iconRenderer = new IconRenderer(percentageRenderer);        
    // apply to columns of data type Double
    table.setDefaultRenderer(Double.class, iconRenderer);
    
    /*   
    // colorize column background
    TableCellRenderer backgroundRenderer2 = new SimpleColumnBackgroundRenderer(defaultRenderer);
    // render as icon and hexadecimal value
    TableCellRenderer colorRenderer = new ColorRenderer(backgroundRenderer2);
    // apply to columns of data type Color
    table.setDefaultRenderer(Color.class, colorRenderer);
    */

    //because a background renderer is already defined you can simplify the
    //lines above by reusing the existing background renderer instance
    TableCellRenderer colorRenderer = new ColorRenderer(backgroundRenderer);
    table.setDefaultRenderer(Color.class, colorRenderer);    
    
    //or without colored background
    //TableCellRenderer colorRenderer = new ColorRenderer(defaultRenderer);
    //table.setDefaultRenderer(Color.class, colorRenderer);

    add(new JScrollPane(table));
    
    setTitle(this.getClass().getSimpleName());
    setDefaultCloseOperation(EXIT_ON_CLOSE);
    setSize(600, 400);
    setLocationRelativeTo(null);
    setVisible(true);
  }

}
