package demo.tablecellrenderer;

import java.awt.Color;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

import demo.tablecellrenderer.renderer.ColorRenderer;
import demo.tablecellrenderer.renderer.IconRenderer;
import demo.tablecellrenderer.renderer.PercentageRenderer;
import demo.tablecellrenderer.renderer.SimpleColumnBackgroundRenderer;
import demo.tablecellrenderer.renderer.SpinnerRenderer;

@SuppressWarnings("serial")
public class SpinnerRendererDemo extends JFrame
{ 
  public static void main(String[] args) throws Exception
  {
    UIManager.setLookAndFeel("de.javasoft.plaf.synthetica.SyntheticaStandardLookAndFeel");
    UIManager.put("Table.alternateRowColor", new Color(0xF3FFFF));
    
    EventQueue.invokeLater(new Runnable()
    {
      public void run()
      {        
        new SpinnerRendererDemo();
      }
    });
  }
  
  public SpinnerRendererDemo()
  {
    JTable table = new JTable(new DemoTableModel(100));

    TableCellRenderer defaultRenderer = table.getDefaultRenderer(Object.class);
    TableCellRenderer backgroundRenderer = new SimpleColumnBackgroundRenderer(defaultRenderer);
    TableCellRenderer percentageRenderer = new PercentageRenderer(backgroundRenderer);
    TableCellRenderer iconRenderer = new IconRenderer(percentageRenderer);        
    table.setDefaultRenderer(Double.class, iconRenderer);

    TableCellRenderer colorRenderer = new ColorRenderer(backgroundRenderer);
    table.setDefaultRenderer(Color.class, colorRenderer);

    //use backgroundRenderer instead of defaultRenderer to highlight table column
    TableCellRenderer spinnerRenderer = new SpinnerRenderer(backgroundRenderer);
    table.setDefaultRenderer(Float.class, spinnerRenderer);

    add(new JScrollPane(table));
    
    setTitle(this.getClass().getSimpleName());
    setDefaultCloseOperation(EXIT_ON_CLOSE);
    setSize(600, 400);
    setLocationRelativeTo(null);
    setVisible(true);
  }

}
