package demo.tablecellrenderer.renderer;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;

import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

public class ColorRenderer implements TableCellRenderer
{
  private TableCellRenderer delegate;
  private ColorIcon icon;

  public ColorRenderer(TableCellRenderer defaultRenderer)
  {
    this.delegate = defaultRenderer;
    icon = new ColorIcon();
  }

  public Component getTableCellRendererComponent(JTable table, Object value, 
                           boolean isSelected, boolean hasFocus, int row, int column) 
  {
    //remember - the default renderer is a label instance for values of data types String, Object and Number    
    Component c = delegate.getTableCellRendererComponent(table, value, isSelected, 
                                                                hasFocus, row, column);
    if (c instanceof JLabel)
    {  
      Color color = (Color)value;
      icon.setColor(color);
      ((JLabel)c).setIcon(icon);
      ((JLabel)c).setText(Integer.toHexString(color.getRGB()).toUpperCase().substring(2));
    }  
    return c;
  }
  
  private static class ColorIcon implements Icon
  {
    private Color color;
    
    public void setColor(Color color)
    {
      this.color = color;
    }
    
    public int getIconHeight()
    {
      return 9;
    }

    public int getIconWidth()
    {
      return 18;
    }

    public void paintIcon(Component c, Graphics g, int x, int y)
    {
      g.setColor(color);
      g.fillRect(x, y, getIconWidth(), getIconHeight());
    }    
  }
} 
